@@ -1,19 +1,30 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
-from __future__ import print_function
-from splunktaucclib.splunk_aoblib.setup_util import Setup_Util
-from splunktaucclib.splunk_aoblib.rest_helper import TARestHelper
-import logging
-from splunktaucclib.logging_helper import get_logger
-from splunktaucclib.cim_actions import ModularAction
-import requests
-from builtins import str
 import csv
 import gzip
+import logging
 import sys
 
+from solnlib import log
+
+from splunktaucclib.cim_actions import ModularAction
+from splunktaucclib.splunk_aoblib.rest_helper import TARestHelper
+from splunktaucclib.splunk_aoblib.setup_util import Setup_Util
+
 try:
     from splunk.clilib.bundle_paths import make_splunkhome_path
 except ImportError:
@@ -25,12 +36,9 @@ sys.path.insert(0, make_splunkhome_path(["etc", "apps", "Splunk_SA_CIM", "lib"])
 class ModularAlertBase(ModularAction):
     def __init__(self, ta_name, alert_name):
         self._alert_name = alert_name
-        # self._logger_name = "modalert_" + alert_name
         self._logger_name = alert_name + "_modalert"
-        self._logger = get_logger(self._logger_name)
-        super(ModularAlertBase, self).__init__(
-            sys.stdin.read(), self._logger, alert_name
-        )
+        self._logger = log.Logs().get_logger(self._logger_name)
+        super().__init__(sys.stdin.read(), self._logger, alert_name)
         self.setup_util_module = None
         self.setup_util = None
         self.result_handle = None
@@ -111,16 +119,16 @@ class ModularAlertBase(ModularAction):
         if proxy and proxy.get("proxy_url") and proxy.get("proxy_type"):
             uri = proxy["proxy_url"]
             if proxy.get("proxy_port"):
-                uri = "{0}:{1}".format(uri, proxy.get("proxy_port"))
+                uri = "{}:{}".format(uri, proxy.get("proxy_port"))
             if proxy.get("proxy_username") and proxy.get("proxy_password"):
-                uri = "{0}://{1}:{2}@{3}/".format(
+                uri = "{}://{}:{}@{}/".format(
                     proxy["proxy_type"],
                     proxy["proxy_username"],
                     proxy["proxy_password"],
                     uri,
                 )
             else:
-                uri = "{0}://{1}".format(proxy["proxy_type"], uri)
+                uri = "{}://{}".format(proxy["proxy_type"], uri)
         return uri
 
     def send_http_request(
@@ -150,7 +158,7 @@ class ModularAlertBase(ModularAction):
         )
 
     def build_http_connection(self, config, timeout=120, disable_ssl_validation=False):
-        from httplib2 import socks, ProxyInfo, Http
+        from httplib2 import Http, ProxyInfo, socks
 
         """
         :config: dict like, proxy and account information are in the following
@@ -231,7 +239,7 @@ class ModularAlertBase(ModularAction):
                 self.pre_handle(num, result)
                 for num, result in enumerate(csv.DictReader(self.result_handle))
             )
-        except IOError:
+        except OSError:
             msg = "Error: {}."
             self.log_error(msg.format("No search result. Cannot send alert action."))
             sys.exit(2)
@@ -266,7 +274,7 @@ class ModularAlertBase(ModularAction):
 
         try:
             status = self.process_event()
-        except IOError:
+        except OSError:
             msg = "Error: {}."
             self.log_error(msg.format("No search result. Cannot send alert action."))
             sys.exit(2)
