@@ -1,23 +1,38 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 # encoding = utf-8
-import importlib
 import copy
+import importlib
+import json
 import logging
 import os
 import sys
-import json
 import tempfile
 
-from splunklib import modularinput as smi
+from solnlib import utils as sutils
 from solnlib.log import Logs
 from solnlib.modular_input import checkpointer
-from solnlib import utils as sutils
+from splunklib import modularinput as smi
 
 from splunktaucclib.global_config import GlobalConfig, GlobalConfigSchema
 from splunktaucclib.splunk_aoblib.rest_helper import TARestHelper
 from splunktaucclib.splunk_aoblib.setup_util import Setup_Util
 
 DATA_INPUTS_OPTIONS = "data_inputs_options"
-AOB_TEST_FLAG = 'AOB_TEST'
+AOB_TEST_FLAG = "AOB_TEST"
 FIELD_TYPE = "type"
 FIELD_FORMAT = "format_type"
 CUSTOMIZED_VAR = "customized_var"
@@ -26,19 +41,22 @@ TYPE_ACCOUNT = "global_account"
 
 
 class BaseModInput(smi.Script):
-    '''
+    """
     This is a modular input wrapper, which provides some helper
     functions to read the paramters from setup pages and the arguments
     from input definition
-    '''
-    LogLevelMapping = {'debug': logging.DEBUG,
-                       'info': logging.INFO,
-                       'warning': logging.WARNING,
-                       'error': logging.ERROR,
-                       'critical': logging.CRITICAL}
+    """
+
+    LogLevelMapping = {
+        "debug": logging.DEBUG,
+        "info": logging.INFO,
+        "warning": logging.WARNING,
+        "error": logging.ERROR,
+        "critical": logging.CRITICAL,
+    }
 
     def __init__(self, app_namespace, input_name, use_single_instance=False):
-        super(BaseModInput, self).__init__()
+        super().__init__()
         self.use_single_instance = use_single_instance
         self._canceled = False
         self.input_type = input_name
@@ -46,8 +64,7 @@ class BaseModInput(smi.Script):
         self.context_meta = {}
         self.namespace = app_namespace
         # redirect all the logging to one file
-        Logs.set_context(namespace=app_namespace,
-                         root_logger_log_file=input_name)
+        Logs.set_context(namespace=app_namespace, root_logger_log_file=input_name)
         self.logger = logging.getLogger()
         self.logger.setLevel(logging.INFO)
         self.rest_helper = TARestHelper(self.logger)
@@ -98,7 +115,7 @@ class BaseModInput(smi.Script):
         self.context_meta = inputs.metadata
         # init setup util
         uri = inputs.metadata["server_uri"]
-        session_key = inputs.metadata['session_key']
+        session_key = inputs.metadata["session_key"]
         self.setup_util = Setup_Util(uri, session_key, self.logger)
 
         input_definition = smi.input_definition.InputDefinition()
@@ -108,6 +125,7 @@ class BaseModInput(smi.Script):
             self.parse_input_args(input_definition)
         except Exception as e:
             import traceback
+
             self.log_error(traceback.format_exc())
             print(traceback.format_exc(), file=sys.stderr)
             # print >> sys.stderr, traceback.format_exc()
@@ -118,12 +136,15 @@ class BaseModInput(smi.Script):
         try:
             self.set_log_level(self.log_level)
         except:
-            self.log_debug('set log level fails.')
+            self.log_debug("set log level fails.")
         try:
             self.collect_events(ew)
         except Exception as e:
             import traceback
-            self.log_error('Get error when collecting events.\n' + traceback.format_exc())
+
+            self.log_error(
+                "Get error when collecting events.\n" + traceback.format_exc()
+            )
             print(traceback.format_exc(), file=sys.stderr)
             # print >> sys.stderr, traceback.format_exc()
             raise RuntimeError(str(e))
@@ -140,7 +161,7 @@ class BaseModInput(smi.Script):
         :param inputs: An ``InputDefinition`` object.
         :return:
         """
-        if os.environ.get(AOB_TEST_FLAG, 'false') == 'true':
+        if os.environ.get(AOB_TEST_FLAG, "false") == "true":
             self._parse_input_args_from_env(inputs)
         else:
             self._parse_input_args_from_global_config(inputs)
@@ -153,13 +174,20 @@ class BaseModInput(smi.Script):
         """
         # dirname at this point will be <splunk_home>/etc/apps/<ta-name>/lib/splunktaucclib/modinput_wrapper, go up 3 dirs from this file to find the root TA directory
         dirname = os.path.dirname
-        config_path = os.path.join(dirname(dirname(dirname(dirname(__file__)))), 'appserver', 'static', 'js', 'build','globalConfig.json')
+        config_path = os.path.join(
+            dirname(dirname(dirname(dirname(__file__)))),
+            "appserver",
+            "static",
+            "js",
+            "build",
+            "globalConfig.json",
+        )
         with open(config_path) as f:
-            schema_json = ''.join([l for l in f])
+            schema_json = "".join([l for l in f])
         global_schema = GlobalConfigSchema(json.loads(schema_json))
 
         uri = inputs.metadata["server_uri"]
-        session_key = inputs.metadata['session_key']
+        session_key = inputs.metadata["session_key"]
         global_config = GlobalConfig(uri, session_key, global_schema)
         ucc_inputs = global_config.inputs.load(input_type=self.input_type)
         all_stanzas = ucc_inputs.get(self.input_type, {})
@@ -173,9 +201,9 @@ class BaseModInput(smi.Script):
         checkbox_fields = self.get_checkbox_fields()
         self.input_stanzas = {}
         for stanza in all_stanzas:
-            full_stanza_name = '{}://{}'.format(self.input_type, stanza.get('name'))
+            full_stanza_name = "{}://{}".format(self.input_type, stanza.get("name"))
             if full_stanza_name in inputs.inputs:
-                if stanza.get('disabled', False):
+                if stanza.get("disabled", False):
                     raise RuntimeError("Running disabled data input!")
                 stanza_params = {}
                 for k, v in stanza.items():
@@ -185,13 +213,13 @@ class BaseModInput(smi.Script):
                         stanza_params[k] = copy.deepcopy(v)
                     else:
                         stanza_params[k] = v
-                self.input_stanzas[stanza.get('name')] = stanza_params
+                self.input_stanzas[stanza.get("name")] = stanza_params
 
     def _parse_input_args_from_env(self, inputs):
         """Parse input arguments from os environment. This is used for testing inputs.
         :param inputs:
         """
-        data_inputs_options = json.loads(os.environ.get(DATA_INPUTS_OPTIONS, '[]'))
+        data_inputs_options = json.loads(os.environ.get(DATA_INPUTS_OPTIONS, "[]"))
         account_fields = self.get_account_fields()
         checkbox_fields = self.get_checkbox_fields()
         self.input_stanzas = {}
@@ -207,7 +235,9 @@ class BaseModInput(smi.Script):
                         arg_value_trans = arg_value
                     stanza_params[arg_name] = arg_value_trans
                     if arg_name in account_fields:
-                        stanza_params[arg_name] = self.get_user_credential_by_id(arg_value_trans)
+                        stanza_params[arg_name] = self.get_user_credential_by_id(
+                            arg_value_trans
+                        )
                     elif arg_name in checkbox_fields:
                         stanza_params[arg_name] = sutils.is_true(arg_value_trans)
                 self.input_stanzas[kind_and_name[1]] = stanza_params
@@ -330,7 +360,17 @@ class BaseModInput(smi.Script):
         return var_value
 
     # Functions to help create events.
-    def new_event(self, data, time=None, host=None, index=None, source=None, sourcetype=None, done=True, unbroken=True):
+    def new_event(
+        self,
+        data,
+        time=None,
+        host=None,
+        index=None,
+        source=None,
+        sourcetype=None,
+        done=True,
+        unbroken=True,
+    ):
         """Create a Splunk event object.
         :param data: ``string``, the event's text.
         :param time: ``float``, time in seconds, including up to 3 decimal places to represent milliseconds.
@@ -342,8 +382,16 @@ class BaseModInput(smi.Script):
         :param unbroken: ``boolean``, Is this event completely encapsulated in this ``Event`` object?
         :return: ``Event`` object
         """
-        return smi.Event(data=data, time=time, host=host, index=index,
-                         source=source, sourcetype=sourcetype, done=done, unbroken=unbroken)
+        return smi.Event(
+            data=data,
+            time=time,
+            host=host,
+            index=index,
+            source=source,
+            sourcetype=sourcetype,
+            done=done,
+            unbroken=unbroken,
+        )
 
     # Basic get functions. To get params in input stanza.
     def get_input_type(self):
@@ -389,8 +437,11 @@ class BaseModInput(smi.Script):
         :return: `dict` or `string` or None
         """
         if input_stanza_name is None:
-            args_dict = {k: args[
-                arg_name] for k, args in self.input_stanzas.items() if arg_name in args}
+            args_dict = {
+                k: args[arg_name]
+                for k, args in self.input_stanzas.items()
+                if arg_name in args
+            }
             if self.use_single_instance:
                 return args_dict
             else:
@@ -405,18 +456,29 @@ class BaseModInput(smi.Script):
         :param input_stanza_name: `string`
         :return: `string` output index
         """
-        return self.get_arg('index', input_stanza_name)
+        return self.get_arg("index", input_stanza_name)
 
     def get_sourcetype(self, input_stanza_name=None):
         """Get sourcetype to index.
         :param input_stanza_name: `string`
         :return: the sourcetype to index to
         """
-        return self.get_arg('sourcetype', input_stanza_name)
+        return self.get_arg("sourcetype", input_stanza_name)
 
     # HTTP request helper
-    def send_http_request(self, url, method, parameters=None, payload=None, headers=None, cookies=None, verify=True,
-                          cert=None, timeout=None, use_proxy=True):
+    def send_http_request(
+        self,
+        url,
+        method,
+        parameters=None,
+        payload=None,
+        headers=None,
+        cookies=None,
+        verify=True,
+        cert=None,
+        timeout=None,
+        use_proxy=True,
+    ):
         """Send http request and get response.
         :param url: URL for the new Request object.
         :param method: method for the new Request object. Can be "GET", "POST", "PUT", "DELETE"
@@ -431,43 +493,61 @@ class BaseModInput(smi.Script):
         :param use_proxy: (optional) whether to use proxy. If set to True, proxy in global setting will be used.
         :return: Response
         """
-        return self.rest_helper.send_http_request(url=url, method=method, parameters=parameters, payload=payload,
-                                                  headers=headers, cookies=cookies, verify=verify, cert=cert,
-                                                  timeout=timeout,
-                                                  proxy_uri=self._get_proxy_uri() if use_proxy else None)
+        return self.rest_helper.send_http_request(
+            url=url,
+            method=method,
+            parameters=parameters,
+            payload=payload,
+            headers=headers,
+            cookies=cookies,
+            verify=verify,
+            cert=cert,
+            timeout=timeout,
+            proxy_uri=self._get_proxy_uri() if use_proxy else None,
+        )
 
     def _get_proxy_uri(self):
         uri = None
         proxy = self.get_proxy()
-        if proxy and proxy.get('proxy_url') and proxy.get('proxy_type'):
-            uri = proxy['proxy_url']
-            if proxy.get('proxy_port'):
-                uri = '{0}:{1}'.format(uri, proxy.get('proxy_port'))
-            if proxy.get('proxy_username') and proxy.get('proxy_password'):
-                uri = '{0}://{1}:{2}@{3}/'.format(proxy['proxy_type'], proxy[
-                    'proxy_username'], proxy['proxy_password'], uri)
+        if proxy and proxy.get("proxy_url") and proxy.get("proxy_type"):
+            uri = proxy["proxy_url"]
+            if proxy.get("proxy_port"):
+                uri = "{}:{}".format(uri, proxy.get("proxy_port"))
+            if proxy.get("proxy_username") and proxy.get("proxy_password"):
+                uri = "{}://{}:{}@{}/".format(
+                    proxy["proxy_type"],
+                    proxy["proxy_username"],
+                    proxy["proxy_password"],
+                    uri,
+                )
             else:
-                uri = '{0}://{1}'.format(proxy['proxy_type'], uri)
+                uri = "{}://{}".format(proxy["proxy_type"], uri)
         return uri
 
     # Checkpointing related functions
     def _init_ckpt(self):
         if self.ckpt is None:
-            if 'AOB_TEST' in os.environ:
-                ckpt_dir = self.context_meta.get('checkpoint_dir', tempfile.mkdtemp())
+            if "AOB_TEST" in os.environ:
+                ckpt_dir = self.context_meta.get("checkpoint_dir", tempfile.mkdtemp())
                 if not os.path.exists(ckpt_dir):
                     os.makedirs(ckpt_dir)
                 self.ckpt = checkpointer.FileCheckpointer(ckpt_dir)
             else:
-                if 'server_uri' not in self.context_meta:
-                    raise ValueError('server_uri not found in input meta.')
-                if 'session_key' not in self.context_meta:
-                    raise ValueError('session_key not found in input meta.')
-                dscheme, dhost, dport = sutils.extract_http_scheme_host_port(self.context_meta[
-                                                                                 'server_uri'])
-                self.ckpt = checkpointer.KVStoreCheckpointer(self.app + "_checkpointer",
-                                                             self.context_meta['session_key'], self.app,
-                                                             scheme=dscheme, host=dhost, port=dport)
+                if "server_uri" not in self.context_meta:
+                    raise ValueError("server_uri not found in input meta.")
+                if "session_key" not in self.context_meta:
+                    raise ValueError("session_key not found in input meta.")
+                dscheme, dhost, dport = sutils.extract_http_scheme_host_port(
+                    self.context_meta["server_uri"]
+                )
+                self.ckpt = checkpointer.KVStoreCheckpointer(
+                    self.app + "_checkpointer",
+                    self.context_meta["session_key"],
+                    self.app,
+                    scheme=dscheme,
+                    host=dhost,
+                    port=dport,
+                )
 
     def get_check_point(self, key):
         """Get checkpoint.
@@ -502,4 +582,3 @@ class BaseModInput(smi.Script):
         if self.ckpt is None:
             self._init_ckpt()
         self.ckpt.delete(key)
-
