@@ -1,11 +1,21 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
-from __future__ import absolute_import
 
 # EAI fields
-from builtins import object
 
 EAI_ACL = "eai:acl"
 EAI_ATTRIBUTES = "eai:attributes"
@@ -21,7 +31,7 @@ EAI_ATTRIBUTES_REQUIRED = "requiredFields"
 EAI_ATTRIBUTES_WILDCARD = "wildcardFields"
 
 
-class RestEAI(object):
+class RestEAI:
     def __init__(self, model, user, app, acl=None):
         self.model = model
         default_acl = {
