@@ -1,22 +1,30 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """
 Validators for Splunk configuration.
 """
 
-from __future__ import absolute_import
 
-import sys
-
-from builtins import object
-import re
 import json
+import re
+import sys
 import warnings
 from inspect import isfunction
 
-
 __all__ = [
     "Validator",
     "ValidationError",
@@ -37,7 +45,7 @@ __all__ = [
 basestring = str if sys.version_info[0] == 3 else basestring
 
 
-class Validator(object):
+class Validator:
     """
     Base class of validators.
     """
@@ -77,7 +85,7 @@ class Validator(object):
             warnings.warn(
                 "`high_priority` arg is deprecated and at a time a single message string is kept in memory."
                 " The last message passed to `put_msg` is returned by `msg` property.",
-                DeprecationWarning
+                FutureWarning,
             )
         self._msg = msg
 
@@ -101,7 +109,7 @@ class AnyOf(Validator):
 
         :param validators: A list of validators.
         """
-        super(AnyOf, self).__init__()
+        super().__init__()
         self._validators = validators
 
     def validate(self, value, data):
@@ -130,7 +138,7 @@ class AllOf(Validator):
 
         :param validators: A list of validators.
         """
-        super(AllOf, self).__init__()
+        super().__init__()
         self._validators = validators
 
     def validate(self, value, data):
@@ -165,7 +173,7 @@ class RequiresIf(Validator):
         assert isinstance(
             fields, (list, set, tuple)
         ), 'Argument "fields" should be list, set or tuple'
-        super(RequiresIf, self).__init__()
+        super().__init__()
         self.fields = fields
         self.condition = condition
 
@@ -218,7 +226,7 @@ class UserDefined(Validator):
 
         :param validator: user-defined validating function
         """
-        super(UserDefined, self).__init__()
+        super().__init__()
         self._validator = validator
         self._args = args
         self._kwargs = kwargs
@@ -243,7 +251,7 @@ class Enum(Validator):
 
         :param values: The collection of valid values
         """
-        super(Enum, self).__init__()
+        super().__init__()
         try:
             self._values = set(values)
         except TypeError:
@@ -273,12 +281,12 @@ class Number(Validator):
 
         assert self._check(min_val) and self._check(
             max_val
-        ), "%(min_val)s & %(max_val)s should be numbers" % {
-            "min_val": min_val,
-            "max_val": max_val,
-        }
+        ), "{min_val} & {max_val} should be numbers".format(
+            min_val=min_val,
+            max_val=max_val,
+        )
 
-        super(Number, self).__init__()
+        super().__init__()
         self._min_val = min_val
         self._max_val = max_val
         self._is_int = is_int
@@ -304,19 +312,17 @@ class Number(Validator):
 
         msg = None
         if not self._min_val and self._max_val and value > self._max_val:
-            msg = "Value should be smaller than %(max_val)s" % {
-                "max_val": self._max_val
-            }
+            msg = "Value should be smaller than {max_val}".format(max_val=self._max_val)
         elif not self._max_val and self._min_val and value < self._min_val:
-            msg = "Value should be no smaller than %(min_val)s" % {
-                "min_val": self._min_val
-            }
+            msg = "Value should be no smaller than {min_val}".format(
+                min_val=self._min_val
+            )
         elif self._min_val and self._max_val:
             if value < self._min_val or value > self._max_val:
-                msg = "Value should be between %(min_val)s and %(max_val)s" % {
-                    "min_val": self._min_val,
-                    "max_val": self._max_val,
-                }
+                msg = "Value should be between {min_val} and {max_val}".format(
+                    min_val=self._min_val,
+                    max_val=self._max_val,
+                )
         if msg is not None:
             self.put_msg(msg)
             return False
@@ -341,12 +347,12 @@ class String(Validator):
 
         assert self._check(min_len) and self._check(
             max_len
-        ), "%(min_len)s & %(max_len)s should be numbers" % {
-            "min_len": min_len,
-            "max_len": max_len,
-        }
+        ), "{min_len} & {max_len} should be numbers".format(
+            min_len=min_len,
+            max_len=max_len,
+        )
 
-        super(String, self).__init__()
+        super().__init__()
         self._min_len, self._max_len = min_len, max_len
 
     def _check(self, val):
@@ -366,19 +372,19 @@ class String(Validator):
         msg = None
 
         if not self._min_len and self._max_len and str_len > self._max_len:
-            msg = "String should be shorter than %(max_len)s" % {
-                "max_len": self._max_len
-            }
+            msg = "String should be shorter than {max_len}".format(
+                max_len=self._max_len
+            )
         elif self._min_len and not self._max_len and str_len < self._min_len:
-            msg = "String should be no shorter than %(min_len)s" % {
-                "min_len": self._min_len
-            }
+            msg = "String should be no shorter than {min_len}".format(
+                min_len=self._min_len
+            )
         elif self._min_len and self._max_len:
             if str_len < self._min_len or str_len > self._max_len:
-                msg = "String length should be between %(min_len)s and %(max_len)s" % {
-                    "min_len": self._min_len,
-                    "max_len": self._max_len,
-                }
+                msg = "String length should be between {min_len} and {max_len}".format(
+                    min_len=self._min_len,
+                    max_len=self._max_len,
+                )
         if msg is not None:
             self.put_msg(msg)
             return False
@@ -396,7 +402,7 @@ class Datetime(Validator):
         :param datetime_format: Date time format,
             e.g. %Y-%m-%dT%H:%M:%S.%f
         """
-        super(Datetime, self).__init__()
+        super().__init__()
         self._format = datetime_format
 
     def validate(self, value, data):
@@ -405,7 +411,7 @@ class Datetime(Validator):
         try:
             datetime.datetime.strptime(value, self._format)
         except ValueError as exc:
-            error = 'Wrong datetime with format "%s": %s' % (self._format, str(exc))
+            error = 'Wrong datetime with format "{}": {}'.format(self._format, str(exc))
             self.put_msg(error)
             return False
         return True
@@ -424,7 +430,7 @@ class Pattern(Validator):
             to be matched.
         :param flags: flags value for regular expression.
         """
-        super(Pattern, self).__init__()
+        super().__init__()
         self._regexp = re.compile(regex, flags=flags)
         self.put_msg("Not matching the pattern: %s" % regex)
 
@@ -442,8 +448,8 @@ class Host(Pattern):
             r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*"
             r"([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$"
         )
-        super(Host, self).__init__(regexp, flags=re.I)
-        self.put_msg("Invalid hostname", high_priority=True)
+        super().__init__(regexp, flags=re.I)
+        self.put_msg("Invalid hostname")
 
 
 class Port(Number):
@@ -452,14 +458,13 @@ class Port(Number):
     """
 
     def __init__(self):
-        super(Port, self).__init__(
+        super().__init__(
             min_val=0,
             max_val=65536,
             is_int=True,
         )
         self.put_msg(
             "Invalid port number, it should be a integer between 0 and 65535",
-            high_priority=True,
         )
 
 
@@ -473,8 +478,8 @@ class Email(Pattern):
             r"^[A-Z0-9][A-Z0-9._%+-]{0,63}@"
             r"(?:[A-Z0-9](?:[A-Z0-9-]{0,62}[A-Z0-9])?\.){1,8}[A-Z]{2,63}$"
         )
-        super(Email, self).__init__(regexp, flags=re.I)
-        self.put_msg("Invalid email address", high_priority=True)
+        super().__init__(regexp, flags=re.I)
+        self.put_msg("Invalid email address")
 
 
 class JsonString(Validator):
